#include <bios.h>
#include <conio.h>
#include <string.h>

#include "standard.h"
#include "i_lib.h"


boolean keypressed()
 /* this procedure returns true if any key has been hit */

{
     if (bioskey(1) == 0) {
          return( FALSE );
        }
     else {
          return( TRUE );
     }
};

key_type readkey()
   /* this procedure will return the next key to be pressed.  this key can */
   /* then be compared to all the normal ascii characters or to any of the */
   /* key characters that have been defined by us */

{

     key_type key;
     unsigned int ch;

     ch = bioskey(0);
     if ((ch & 0x00FF)==0) ch = (ch >> 8) + 300;
     else ch=ch & 0x00FF;
     key = (key_type)ch;
     return( key );

};

void keyboard_status( kbstat )
   /* this procedure will return a status word which CAN and be bitwise anded */
   /* with the predefined keyboard statuses inorder to find out which     */
   /* keyboard options are set */

kbstat_type *kbstat;

{
     *kbstat = bioskey( 2 );
};


/*
ͻ
 Routine      Author : David J. Yazel                                      
              Date :   October 24, 1989                                    
              Name :   key_name()                                          
Ķ
 Description  This routine will return the string representation of the    
              key specified.  This is for printing the keys out for the    
              user.                                                        
Ķ
 Returns      Pointer to a string containing the name.                     
ͼ  
*/

char *key_name( key )

int key;

begin


    switch(key)
      begin

        case BACKSPACE           : return("BACKSPACE"); 
        case TAB                 : return("TAB"); 
        case LINE_FEED           : return("LINE_FEED"); 
        case ENTER               : return("ENTER"); 
        case ESCAPE              : return("ESCAPE"); 
        case F1                  : return("F1"); 
        case F2                  : return("F2"); 
        case F3                  : return("F3"); 
        case F4                  : return("F4"); 
        case F5                  : return("F5"); 
        case F6                  : return("F6"); 
        case F7                  : return("F7"); 
        case F8                  : return("F8"); 
        case F9                  : return("F9"); 
        case F10                 : return("F10"); 
        case F11                 : return("F11"); 
        case F12                 : return("F12"); 
        case SHIFT_F1            : return("SHIFT/F1"); 
        case SHIFT_F2            : return("SHIFT/F2"); 
        case SHIFT_F3            : return("SHIFT/F3"); 
        case SHIFT_F4            : return("SHIFT/F4"); 
        case SHIFT_F5            : return("SHIFT/F5"); 
        case SHIFT_F6            : return("SHIFT/F6"); 
        case SHIFT_F7            : return("SHIFT/F7"); 
        case SHIFT_F8            : return("SHIFT/F8"); 
        case SHIFT_F9            : return("SHIFT/F9"); 
        case SHIFT_F10           : return("SHIFT/F10"); 
        case SHIFT_F11           : return("SHIFT/F11"); 
        case SHIFT_F12           : return("SHIFT/F12"); 
        case CTRL_F1             : return("CTRL/F1"); 
        case CTRL_F2             : return("CTRL/F2"); 
        case CTRL_F3             : return("CTRL/F3"); 
        case CTRL_F4             : return("CTRL/F4"); 
        case CTRL_F5             : return("CTRL/F5"); 
        case CTRL_F6             : return("CTRL/F6"); 
        case CTRL_F7             : return("CTRL/F7"); 
        case CTRL_F8             : return("CTRL/F8"); 
        case CTRL_F9             : return("CTRL/F9"); 
        case CTRL_F10            : return("CTRL/F10"); 
        case CTRL_F11            : return("CTRL/F11"); 
        case CTRL_F12            : return("CTRL/F12"); 
        case ALT_F1              : return("ALT/F1"); 
        case ALT_F2              : return("ALT/F2"); 
        case ALT_F3              : return("ALT/F3"); 
        case ALT_F4              : return("ALT/F4"); 
        case ALT_F5              : return("ALT/F5"); 
        case ALT_F6              : return("ALT/F6"); 
        case ALT_F7              : return("ALT/F7"); 
        case ALT_F8              : return("ALT/F8"); 
        case ALT_F9              : return("ALT/F9"); 
        case ALT_F10             : return("ALT/F10"); 
        case ALT_F11             : return("ALT/F11"); 
        case ALT_F12             : return("ALT/F12"); 
        case LEFT_ARROW          : return("LEFT ARROW"); 
        case RIGHT_ARROW         : return("RIGHT ARROW"); 
        case UP_ARROW            : return("UP ARROW"); 
        case DOWN_ARROW          : return("DOWN ARROW"); 
        case HOME                : return("HOME"); 
        case END                 : return("END"); 
        case PGUP                : return("PGUP"); 
        case PGDN                : return("PGDN"); 
        case INS                 : return("INS"); 
        case DEL                 : return("DEL"); 
        case CTRL_LEFT_ARROW     : return("CTRL/LEFT ARROW"); 
        case CTRL_RIGHT_ARROW    : return("CTRL/RIGHT ARROW"); 
        case CTRL_UP_ARROW       : return("CTRL/UP ARROW"); 
        case CTRL_DOWN_ARROW     : return("CTRL/DOWN ARROW"); 
        case CTRL_HOME           : return("CTRL/HOME"); 
        case CTRL_END            : return("CTRL/END"); 
        case CTRL_PGUP           : return("CTRL/PGUP"); 
        case CTRL_PGDN           : return("CTRL/PGDN"); 
        case CTRL_INS            : return("CTRL/INS"); 
        case CTRL_DEL            : return("CTRL/DEL"); 
        case ALT_LEFT_ARROW      : return("ALT/LEFT ARROW"); 
        case ALT_RIGHT_ARROW     : return("ALT/RIGHT ARROW"); 
        case ALT_UP_ARROW        : return("ALT/UP ARROW"); 
        case ALT_DOWN_ARROW      : return("ALT/DOWN ARROW"); 
        case ALT_HOME            : return("ALT/HOME"); 
        case ALT_END             : return("ALT/END"); 
        case ALT_PGUP            : return("ALT/PGUP"); 
        case ALT_PGDN            : return("ALT/PGDN"); 
        case ALT_INS             : return("ALT/INS"); 
        case ALT_DEL             : return("ALT/DEL"); 
        case SHIFT_TAB           : return("SHIFT TAB"); 
        case ALT_A               : return("ALT/A"); 
        case ALT_B               : return("ALT/B"); 
        case ALT_C               : return("ALT/C"); 
        case ALT_D               : return("ALT/D"); 
        case ALT_E               : return("ALT/E"); 
        case ALT_F               : return("ALT/F"); 
        case ALT_G               : return("ALT/G"); 
        case ALT_H               : return("ALT/H"); 
        case ALT_I               : return("ALT/I"); 
        case ALT_J               : return("ALT/J"); 
        case ALT_K               : return("ALT/K"); 
        case ALT_L               : return("ALT/L"); 
        case ALT_M               : return("ALT/M"); 
        case ALT_N               : return("ALT/N"); 
        case ALT_O               : return("ALT/O"); 
        case ALT_P               : return("ALT/P"); 
        case ALT_Q               : return("ALT/Q"); 
        case ALT_R               : return("ALT/R"); 
        case ALT_S               : return("ALT/S"); 
        case ALT_T               : return("ALT/T"); 
        case ALT_U               : return("ALT/U"); 
        case ALT_V               : return("ALT/V"); 
        case ALT_W               : return("ALT/W"); 
        case ALT_X               : return("ALT/X"); 
        case ALT_Y               : return("ALT/Y"); 
        case ALT_Z               : return("ALT/Z"); 
        case CTRL_2              : return("CTRL/2"); 
        case ALT_0               : return("ALT/0"); 
        case ALT_1               : return("ALT/1"); 
        case ALT_2               : return("ALT/2"); 
        case ALT_3               : return("ALT/3"); 
        case ALT_4               : return("ALT/4"); 
        case ALT_5               : return("ALT/5"); 
        case ALT_6               : return("ALT/6"); 
        case ALT_7               : return("ALT/7"); 
        case ALT_8               : return("ALT/8"); 
        case ALT_9               : return("ALT/9"); 
        case CTRL_ASTERIC        : return("CTRL/ASTERIC"); 
        case ALT_MINUS           : return("ALT/MINUS"); 
        case ALT_EQUAL           : return("ALT/EQUAL"); 

        default                  : return("UNKNOWN"); 

      end
end
