/*
ͻ
 Module       Author : David J. Yazel                                      
              Date :   December 1, 1989                                    
              Name :   I_LIB.H                                             
Ķ
 Description  This is the header file for the three modules I_MOUSE, I_KEYS
              and I_INPUT.                                                 
ͼ  
*/


#ifndef I_LIB_INCLUDE
#define I_LIB_INCLUDE

#include "standard.h"
#include <time.h>

/* these define all the different types of input actions the        */
/* user can make through the two input devices : mouse and keyboard */

#define I_KKEYHIT     0
#define I_MPUSH_R     1
#define I_MPUSH_L     2
#define I_MRELEASE_R  3
#define I_MRELEASE_L  4
#define I_MMOVE       5
#define I_MCLICK_L    6
#define I_MCLICK_R    7
#define I_MDBLCLICK_L 8
#define I_MDBLCLICK_R 9

/*  statuses returned by keyboard status */

#define RIGHT_SHIFT      0x01
#define LEFT_SHIFT       0x02
#define CTRL_KEY         0x04
#define ALT_KEY          0x08
#define SCROLL_LOCK      0x10
#define NUM_LOCK         0x20
#define CAPS_LOCK        0x40
#define INSERT_MODE      0x80



#define BACKSPACE    8
#define TAB          9
#define LINE_FEED   10
#define ENTER       13
#define ESCAPE      27

#define F1         359
#define F2         360           
#define F3         361           
#define F4         362           
#define F5         363           
#define F6         364           
#define F7         365           
#define F8         366           
#define F9         367           
#define F10        368
#define F11        433
#define F12        434

#define SHIFT_F1   384      
#define SHIFT_F2   385      
#define SHIFT_F3   386      
#define SHIFT_F4   387      
#define SHIFT_F5   388      
#define SHIFT_F6   389      
#define SHIFT_F7   390      
#define SHIFT_F8   391      
#define SHIFT_F9   392           
#define SHIFT_F10  393
#define SHIFT_F11  435
#define SHIFT_F12  436

#define CTRL_F1    394
#define CTRL_F2    395     
#define CTRL_F3    396     
#define CTRL_F4    397     
#define CTRL_F5    398     
#define CTRL_F6    399     
#define CTRL_F7    400     
#define CTRL_F8    401     
#define CTRL_F9    402           
#define CTRL_F10   403
#define CTRL_F11   437
#define CTRL_F12   438

#define ALT_F1     404
#define ALT_F2     405
#define ALT_F3     406
#define ALT_F4     407
#define ALT_F5     408
#define ALT_F6     409
#define ALT_F7     410
#define ALT_F8     411
#define ALT_F9     412
#define ALT_F10    413
#define ALT_F11    439
#define ALT_F12    440

#define LEFT_ARROW           375
#define RIGHT_ARROW          377
#define UP_ARROW             372
#define DOWN_ARROW           380
#define HOME                 371
#define END                  379                                
#define PGUP                 373
#define PGDN                 381
#define INS                  382
#define DEL                  383

#define CTRL_LEFT_ARROW      415
#define CTRL_RIGHT_ARROW     416
#define CTRL_UP_ARROW        460
#define CTRL_DOWN_ARROW      464
#define CTRL_HOME            419                                
#define CTRL_END             417                                
#define CTRL_PGUP            432
#define CTRL_PGDN            418
#define CTRL_INS             465
#define CTRL_DEL             466

#define ALT_LEFT_ARROW       478
#define ALT_RIGHT_ARROW      480
#define ALT_UP_ARROW         475
#define ALT_DOWN_ARROW       483
#define ALT_HOME             474                                
#define ALT_END              482                                
#define ALT_PGUP             476
#define ALT_PGDN             484
#define ALT_INS              485
#define ALT_DEL              486

#define SHIFT_TAB            315

#define ALT_A      330
#define ALT_B      348
#define ALT_C      346
#define ALT_D      332
#define ALT_E      318
#define ALT_F      333
#define ALT_G      334
#define ALT_H      335
#define ALT_I      323
#define ALT_J      336
#define ALT_K      337
#define ALT_L      338
#define ALT_M      350
#define ALT_N      349
#define ALT_O      324
#define ALT_P      325
#define ALT_Q      316
#define ALT_R      319
#define ALT_S      331
#define ALT_T      320
#define ALT_U      322
#define ALT_V      347
#define ALT_W      317
#define ALT_X      345
#define ALT_Y      321
#define ALT_Z      344

#define CTRL_2    303

#define ALT_0     429
#define ALT_1     420
#define ALT_2     421
#define ALT_3     422
#define ALT_4     423
#define ALT_5     424
#define ALT_6     425
#define ALT_7     426
#define ALT_8     427
#define ALT_9     428

#define CTRL_ASTERIC  414

#define ALT_MINUS  430
#define ALT_EQUAL  431

typedef unsigned short  kbstat_type;

typedef unsigned short  key_type;

/* the following structure is used to hold information about a */
/* mouse action which has taken place */

typedef struct

{

  unsigned func;     /* function which the mouse did */
  unsigned x,y;      /* location at the time of the function */
  int key;           /* key pressed, if any */
  clock_t clock;

} I_input_t;


/*  */

/* The following define the routines exported from this module */

extern boolean I_get_mouse( I_input_t *input );
extern boolean I_mouse();
extern void I_get( I_input_t *input );

#if ANSI

extern void keyboard_status( kbstat_type * );
   /* this procedure will return a status word which CAN and be bitwise anded */
   /* with the predefined keyboard statuses inorder to find out which     */
   /* keyboard options are set */

extern key_type readkey( void );
   /* this procedure will return the next key to be pressed.  this key can */
   /* then be compared to all the normal ascii characters or to any of the */
   /* key characters that have been defined by us */

extern boolean keypressed( void );
   /* this procedure will return true if a key has been pressed */

extern char *key_name( int key );

#else

extern void keyboard_status();

extern key_type readkey();

extern boolean keypressed();

extern char *key_name();

#endif 



#endif
